from gex.lib.utils import blob


def extract(bytes):
    print("NYI")
